@@ -38,6 +38,7 @@ OC.L10N.register(
     "Aliases" : "Aizstājvārdi",
     "Signature" : "Paraksts",
     "Filters" : "Filtri",
+    "Rename alias" : "Pārdēvēt aizstājvārdu",
     "Go back" : "Atpakaļ",
     "Email address" : "E-pasta adrese",
     "Cancel" : "Atcelt",
@@ -46,7 +47,7 @@ OC.L10N.register(
     "General" : "Vispārīgs",
     "Keyboard shortcuts" : "Tastatūras saīsnes",
     "Archive" : "Arhīvi",
-    "Delete" : "Dzēst",
+    "Delete" : "Izdzēst",
     "Search" : "Meklēt",
     "Send" : "Sūtīt",
     "Refresh" : "Atsvaidzināt",
@@ -96,7 +97,8 @@ OC.L10N.register(
     "Remove account" : "Noņemt kontu",
     "Quota" : "Kvota",
     "Saving" : "Saglabā",
-    "Rename" : "Pārsaukt",
+    "An error occurred, unable to rename the mailbox." : "Atgadījās kļūda, nevar pārdēvēt pastkasti.",
+    "Rename" : "Pārdēvēt",
     "Subscribed" : "Abonēts",
     "New message" : "Jauna ziņa",
     "Reply" : "Atbildēt",
@@ -115,7 +117,8 @@ OC.L10N.register(
     "Select tags" : "Atlasīt birkas",
     "From me" : "No manis",
     "Custom" : "Pielāgots",
-    "Delete tag" : "Dzēst atzīmi",
+    "An error occurred, unable to rename the tag." : "Atgadījās kļūda, nevar pārdēvēt birku.",
+    "Delete tag" : "Izdzēst birku",
     "Tag name is a hidden system tag" : "Birkas nosaukums ir slēpta sistēmas birka",
     "Tag already exists" : "Birka jau pastāv",
     "Not found" : "Nav atrasts",
